==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkTableToDatabaseWriter.java <==
// java wrapper for vtkTableToDatabaseWriter object
//

package vtk;
import vtk.*;

public class vtkTableToDatabaseWriter extends vtkWriter
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean SetDatabase_2(vtkSQLDatabase id0);
  public boolean SetDatabase(vtkSQLDatabase id0)
    { return SetDatabase_2(id0); }

  private native boolean SetTableName_3(String id0);
  public boolean SetTableName(String id0)
    { return SetTableName_3(id0); }

  private native boolean TableNameIsNew_4();
  public boolean TableNameIsNew()
    { return TableNameIsNew_4(); }

  private native long GetDatabase_5();
  public vtkSQLDatabase GetDatabase() {
    long temp = GetDatabase_5();

    if (temp == 0) return null;
    return (vtkSQLDatabase)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_6();
  public vtkTable GetInput() {
    long temp = GetInput_6();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_7(int id0);
  public vtkTable GetInput(int id0) {
    long temp = GetInput_7(id0);

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkTableToDatabaseWriter() { super(); }

  public vtkTableToDatabaseWriter(long id) { super(id); }

}

==> vtk-8.2.0-9-armv7h.pkg.tar.xz: vtk/vtkTableToDatabaseWriter.java <==
// java wrapper for vtkTableToDatabaseWriter object
//

package vtk;
import vtk.*;

public class vtkTableToDatabaseWriter extends vtkWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean SetDatabase_2(vtkSQLDatabase id0);
  public boolean SetDatabase(vtkSQLDatabase id0)
    { return SetDatabase_2(id0); }

  private native boolean SetTableName_3(String id0);
  public boolean SetTableName(String id0)
    { return SetTableName_3(id0); }

  private native boolean TableNameIsNew_4();
  public boolean TableNameIsNew()
    { return TableNameIsNew_4(); }

  private native long GetDatabase_5();
  public vtkSQLDatabase GetDatabase() {
    long temp = GetDatabase_5();

    if (temp == 0) return null;
    return (vtkSQLDatabase)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_6();
  public vtkTable GetInput() {
    long temp = GetInput_6();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_7(int id0);
  public vtkTable GetInput(int id0) {
    long temp = GetInput_7(id0);

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkTableToDatabaseWriter() { super(); }

  public vtkTableToDatabaseWriter(long id) { super(id); }

}
